@@ -1,7 +1,7 @@
 import sys
+from queue import Queue
 
-
-from je_auto_control.utils.exception.exception_tag import osx_import_error
+from je_auto_control.utils.exception.exception_tags import osx_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
 
 if sys.platform not in ["darwin"]:
@@ -15,24 +15,19 @@ from je_auto_control.utils.exception.exceptions import AutoControlJsonActionExce
 
 class OSXRecorder(object):
 
-    def record(self):
+    def __init__(self):
+        self.record_flag = False
+
+    def record(self) -> None:
+        self.record_flag = True
         osx_record()
 
-    def stop_record(self):
+    def stop_record(self) -> Queue:
         record_queue = osx_stop_record()
+        self.record_flag = False
         if record_queue is None:
             raise AutoControlJsonActionException
         return osx_stop_record()
 
 
 osx_recorder = OSXRecorder()
-
-if __name__ == "__main__":
-    test_osx_recorder = OSXRecorder()
-    test_osx_recorder.record()
-    temp = test_osx_recorder.stop_record()
-    print(temp)
-    for action in temp.queue:
-        print(action)
-    while True:
-        pass
