@@ -14,8 +14,8 @@ def read_action_json(json_file_path: str) -> list:
     use to read action file
     :param json_file_path json file's path to read
     """
+    _lock.acquire()
     try:
-        _lock.acquire()
         file_path = Path(json_file_path)
         if file_path.exists() and file_path.is_file():
             with open(json_file_path) as read_file:
@@ -32,10 +32,10 @@ def write_action_json(json_save_path: str, action_json: list) -> None:
     :param json_save_path  json save path
     :param action_json the json str include action to write
     """
+    _lock.acquire()
     try:
-        _lock.acquire()
         with open(json_save_path, "w+") as file_to_write:
-            file_to_write.write(json.dumps(action_json))
+            file_to_write.write(json.dumps(action_json, indent=4))
     except AutoControlJsonActionException:
         raise AutoControlJsonActionException(cant_save_json_error)
     finally:
